==> zio-aws-sfn_2.12-7.28.29.6-sources.jar: zio/aws/sfn/model/DescribeStateMachineForExecutionRequest.scala <==
package zio.aws.sfn.model
import zio.ZIO
import zio.aws.sfn.model.primitives.Arn
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeStateMachineForExecutionRequest(
    executionArn: Arn,
    includedData: Optional[zio.aws.sfn.model.IncludedData] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sfn.model.DescribeStateMachineForExecutionRequest = {
    import DescribeStateMachineForExecutionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sfn.model.DescribeStateMachineForExecutionRequest
      .builder()
      .executionArn(Arn.unwrap(executionArn): java.lang.String)
      .optionallyWith(includedData.map(value => value.unwrap))(_.includedData)
      .build()
  }
  def asReadOnly
      : zio.aws.sfn.model.DescribeStateMachineForExecutionRequest.ReadOnly =
    zio.aws.sfn.model.DescribeStateMachineForExecutionRequest
      .wrap(buildAwsValue())
}
object DescribeStateMachineForExecutionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sfn.model.DescribeStateMachineForExecutionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sfn.model.DescribeStateMachineForExecutionRequest =
      zio.aws.sfn.model.DescribeStateMachineForExecutionRequest(
        executionArn,
        includedData.map(value => value)
      )
    def executionArn: Arn
    def includedData: Optional[zio.aws.sfn.model.IncludedData]
    def getExecutionArn: ZIO[Any, Nothing, Arn] = ZIO.succeed(executionArn)
    def getIncludedData: ZIO[Any, AwsError, zio.aws.sfn.model.IncludedData] =
      AwsError.unwrapOptionField("includedData", includedData)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sfn.model.DescribeStateMachineForExecutionRequest
  ) extends zio.aws.sfn.model.DescribeStateMachineForExecutionRequest.ReadOnly {
    override val executionArn: Arn =
      zio.aws.sfn.model.primitives.Arn(impl.executionArn())
    override val includedData: Optional[zio.aws.sfn.model.IncludedData] =
      zio.aws.core.internal
        .optionalFromNullable(impl.includedData())
        .map(value => zio.aws.sfn.model.IncludedData.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sfn.model.DescribeStateMachineForExecutionRequest
  ): zio.aws.sfn.model.DescribeStateMachineForExecutionRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-sfn_3-5.17.195.2-sources.jar: zio/aws/sfn/model/DescribeStateMachineForExecutionRequest.scala <==
package zio.aws.sfn.model
import zio.ZIO
import zio.aws.sfn.model.primitives.Arn
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeStateMachineForExecutionRequest(executionArn: Arn) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sfn.model.DescribeStateMachineForExecutionRequest = {
    import DescribeStateMachineForExecutionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sfn.model.DescribeStateMachineForExecutionRequest
      .builder()
      .executionArn(Arn.unwrap(executionArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.sfn.model.DescribeStateMachineForExecutionRequest.ReadOnly =
    zio.aws.sfn.model.DescribeStateMachineForExecutionRequest
      .wrap(buildAwsValue())
}
object DescribeStateMachineForExecutionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sfn.model.DescribeStateMachineForExecutionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sfn.model.DescribeStateMachineForExecutionRequest =
      zio.aws.sfn.model.DescribeStateMachineForExecutionRequest(executionArn)
    def executionArn: Arn
    def getExecutionArn: ZIO[Any, Nothing, Arn] = ZIO.succeed(executionArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sfn.model.DescribeStateMachineForExecutionRequest
  ) extends zio.aws.sfn.model.DescribeStateMachineForExecutionRequest.ReadOnly {
    override val executionArn: Arn =
      zio.aws.sfn.model.primitives.Arn(impl.executionArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.sfn.model.DescribeStateMachineForExecutionRequest
  ): zio.aws.sfn.model.DescribeStateMachineForExecutionRequest.ReadOnly =
    new Wrapper(impl)
}
